library(geoChronR)
library(magrittr)
library(ggplot2)
library(lipdR)

library(plyr)
library(dplyr)
library(tidyr)
library(patchwork)



#GGC90ML, Lacerra 2019
GGC90ML <- lipdR::readLipd("D:/WHOI/Research/Holocene_AMOC/geoChronR/LiPD/KNR159-5-90GGC.Lacerra.2019.lpd")

GGC90ML = runBacon(GGC90ML,
                 chron.num = 1,
                 model.num = 1,
                 meas.table.num = NA,
                 bacon.dir = "D:/WHOI/Research/Holocene_AMOC/geoChronR/Bacon_runs",
                 lab.id.var = 'labid',
                 age.14c.var = 'age14c', 
                 age.14c.uncertainty.var = 'age14cunc', 
                 age.var = 'age', 
                 age.uncertainty.var = 'ageunc',
                 depth.var = 'depth', 
                 reservoir.age.14c.var = 'dR',
                 reservoir.age.14c.uncertainty.var = 'dSTD', 
                 rejected.ages.var = NULL,
                 cc = 2, #all 14C dates use marine20
                 bacon.thick = 5,
                 bacon.acc.mean = 20,
                 plot.pdf = FALSE,
                 overwrite = TRUE)

#map the model ensemble values to a measurement table in paleoData

GGC90ML_Cp <- mapAgeEnsembleToPaleoData(GGC90ML,age.var = "ageEnsemble",paleo.meas.table.num = 1)

#Select age

GGC90ML.C.p.ae <- selectData(GGC90ML_Cp,var.name = "ageEnsemble",meas.table.num = 1)


#select variables
GGC90ML.C.p.depth <- selectData(GGC90ML_Cp,var.name = "Depth",meas.table.num = 1)
GGC90ML.C.p.BCa <- selectData(GGC90ML_Cp,var.name = "B/Ca",meas.table.num = 1)
GGC90ML.C.p.dCO3 <- selectData(GGC90ML_Cp,var.name = "dCO3",meas.table.num = 1)


# export data with x as median Bacon age, y as raw data

GGC90ML.C.p.raw <- data.frame(GGC90ML.C.p.depth$values,
                            apply(GGC90ML.C.p.ae$values, 1, median),
                            GGC90ML.C.p.BCa$values,
                            GGC90ML.C.p.dCO3$values
                            )

GGC90ML.C.p.raw <- rename(GGC90ML.C.p.raw,
                        c("Depth" = "GGC90ML.C.p.depth.values",
                          "median_age" = "apply.GGC90ML.C.p.ae.values..1..median.",
                          "BCa" = "GGC90ML.C.p.BCa.values",
                          "dCO3" = "GGC90ML.C.p.dCO3.values"
                          ))

write.csv(GGC90ML.C.p.raw, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\GGC90ML.C.p.raw.csv",row.names = FALSE)

dCO3.plot <- GGC90ML.C.p.raw %>%
  ggplot()+
  geom_point(aes(x = median_age/1000, y = dCO3))+
  geom_line(aes(x = median_age/1000, y = dCO3))+
  theme_bw()+
  theme(axis.line = element_line(color='black'),
        plot.background = element_blank(),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank())+
  #theme(legend.position="none")+
  ggtitle("C.p. dCO3")

print(dCO3.plot)

#ribbon
GGC90ML.C.p.dCO3.rec05 <- plotTimeseriesEnsRibbons(X = GGC90ML.C.p.ae,Y = GGC90ML.C.p.dCO3, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90ML.C.p.dCO3.rec05 <- rename(GGC90ML.C.p.dCO3.rec05,c("median_dCO3" = "0.5"))

GGC90ML.C.p.dCO3.rec025 <- plotTimeseriesEnsRibbons(X = GGC90ML.C.p.ae,Y = GGC90ML.C.p.dCO3, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90ML.C.p.dCO3.rec025 <- rename(GGC90ML.C.p.dCO3.rec025,c("lower025_dCO3" = "0.25"))

GGC90ML.C.p.dCO3.rec075 <- plotTimeseriesEnsRibbons(X = GGC90ML.C.p.ae,Y = GGC90ML.C.p.dCO3, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90ML.C.p.dCO3.rec075 <- rename(GGC90ML.C.p.dCO3.rec075,c("upper075_dCO3" = "0.75"))

GGC90ML.C.p.dCO3.rec0025 <- plotTimeseriesEnsRibbons(X = GGC90ML.C.p.ae,Y = GGC90ML.C.p.dCO3, probs = 0.025, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90ML.C.p.dCO3.rec0025 <- rename(GGC90ML.C.p.dCO3.rec0025,c("lower0025_dCO3" = "0.025"))

GGC90ML.C.p.dCO3.rec0975 <- plotTimeseriesEnsRibbons(X = GGC90ML.C.p.ae,Y = GGC90ML.C.p.dCO3, probs = 0.975, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90ML.C.p.dCO3.rec0975 <- rename(GGC90ML.C.p.dCO3.rec0975,c("upper0975_dCO3" = "0.975"))


GGC90ML.C.p.rec <- data.frame(GGC90ML.C.p.dCO3.rec05$ages,
                              GGC90ML.C.p.dCO3.rec05$median_dCO3,
                              GGC90ML.C.p.dCO3.rec025$lower025_dCO3,
                              GGC90ML.C.p.dCO3.rec075$upper075_dCO3,
                              GGC90ML.C.p.dCO3.rec0025$lower0025_dCO3,
                              GGC90ML.C.p.dCO3.rec0975$upper0975_dCO3)

GGC90ML.C.p.rec <- rename(GGC90ML.C.p.rec,c("age" = "GGC90ML.C.p.dCO3.rec05.ages",
                                            "median_dCO3" = "GGC90ML.C.p.dCO3.rec05.median_dCO3",
                                            "lower025_dCO3" = "GGC90ML.C.p.dCO3.rec025.lower025_dCO3",
                                            "upper075_dCO3" = "GGC90ML.C.p.dCO3.rec075.upper075_dCO3",
                                            "lower005_dCO3" = "GGC90ML.C.p.dCO3.rec0025.lower0025_dCO3",
                                            "upper095_dCO3" = "GGC90ML.C.p.dCO3.rec0975.upper0975_dCO3"))

write.csv(GGC90ML.C.p.rec, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\GGC90ML.C.p.rib.csv",row.names = FALSE)

#ribbon fig
GGC90ML.C.p.dCO3.plot1 <- plotTimeseriesEnsRibbons(X = GGC90ML.C.p.ae,
                                                   Y = GGC90ML.C.p.dCO3,
                                                   probs = c(0.025, 0.25, 0.5, 0.75, 0.975),
                                                   n.bins = 209,
                                                   alp = 0.2, 
                                                   color.low = "Blue",
                                                   color.high = "Blue",
                                                   color.line = "Blue"
)+
  xlim(c(0,35000))+
  ylim(c(40,100))+
  ggtitle("GGC90ML C.p. dCO3")

GGC90ML.C.p.dCO3.plot2 <- plotScatterEns(X = apply(GGC90ML.C.p.ae$values, 1, median), Y = GGC90ML.C.p.dCO3$values, alp = 1, add.to.plot = GGC90ML.C.p.dCO3.plot1)

print(GGC90ML.C.p.dCO3.plot2)