library(geoChronR)
library(magrittr)
library(ggplot2)
library(lipdR)

library(plyr)
library(dplyr)
library(tidyr)
library(patchwork)



#CDH46, Oppo2023
CDH46 <- lipdR::readLipd("D:/WHOI/Research/Holocene_AMOC/geoChronR/LiPD/KNR197-3-46CDH.Oppo.2023.lpd")

CDH46 = runBacon(CDH46,
                 chron.num = 1,
                 model.num = 1,
                 meas.table.num = NA,
                 bacon.dir = "D:/WHOI/Research/Holocene_AMOC/geoChronR/Bacon_runs",
                 lab.id.var = 'labid',
                 age.14c.var = 'age14c', 
                 age.14c.uncertainty.var = 'age14cunc', 
                 age.var = 'age', 
                 age.uncertainty.var = 'ageunc',
                 depth.var = 'depth', 
                 reservoir.age.14c.var = 'dR',
                 reservoir.age.14c.uncertainty.var = 'dSTD', 
                 rejected.ages.var = NULL,
                 cc = c(2,2,2,2,2,2,2,0,2,2,2,2,2,2,2,2,2,2), #all 14C dates use marine20, except d18O_tiepoint, do not calibrate it
                 bacon.thick = 5,
                 bacon.acc.mean = 20,
                 plot.pdf = FALSE,
                 overwrite = TRUE)

#map the model ensemble values to a measurement table in paleoData

CDH46_He <- mapAgeEnsembleToPaleoData(CDH46,age.var = "ageEnsemble",paleo.meas.table.num = 1)
CDH46_Up <- mapAgeEnsembleToPaleoData(CDH46,age.var = "ageEnsemble",paleo.meas.table.num = 2)
CDH46_Cp <- mapAgeEnsembleToPaleoData(CDH46,age.var = "ageEnsemble",paleo.meas.table.num = 3)
CDH46_Iso <- mapAgeEnsembleToPaleoData(CDH46,age.var = "ageEnsemble",paleo.meas.table.num = 4)

#Select age

CDH46.H.e.ae <- selectData(CDH46_He,var.name = "ageEnsemble",meas.table.num = 1)
CDH46.U.p.ae <- selectData(CDH46_Up,var.name = "ageEnsemble",meas.table.num = 2)
CDH46.C.p.ae <- selectData(CDH46_Cp,var.name = "ageEnsemble",meas.table.num = 3)
CDH46.I.so.ae <- selectData(CDH46_Iso,var.name = "ageEnsemble",meas.table.num = 4)


#select variables
CDH46.H.e.depth <- selectData(CDH46_He,var.name = "Depth",meas.table.num = 1)
CDH46.H.e.LiCa <- selectData(CDH46_He,var.name = "Li/Ca",meas.table.num = 1)
CDH46.H.e.MgCa <- selectData(CDH46_He,var.name = "Mg/Ca",meas.table.num = 1)
CDH46.H.e.MgLi <- selectData(CDH46_He,var.name = "Mg/Li",meas.table.num = 1)
CDH46.H.e.CdCa <- selectData(CDH46_He,var.name = "Cd/Ca",meas.table.num = 1)
CDH46.H.e.BCa <- selectData(CDH46_He,var.name = "B/Ca",meas.table.num = 1)
CDH46.H.e.UCa <- selectData(CDH46_He,var.name = "U/Ca",meas.table.num = 1)
CDH46.H.e.MnCa <- selectData(CDH46_He,var.name = "Mn/Ca",meas.table.num = 1)
CDH46.H.e.FeCa <- selectData(CDH46_He,var.name = "Fe/Ca",meas.table.num = 1)
CDH46.H.e.AlCa <- selectData(CDH46_He,var.name = "Al/Ca",meas.table.num = 1)
CDH46.H.e.BWT <- selectData(CDH46_He,var.name = "BWT",meas.table.num = 1)
CDH46.H.e.CdW <- selectData(CDH46_He,var.name = "CdW",meas.table.num = 1)

CDH46.U.p.depth <- selectData(CDH46_Up,var.name = "Depth",meas.table.num = 2)
CDH46.U.p.LiCa <- selectData(CDH46_Up,var.name = "Li/Ca",meas.table.num = 2)
CDH46.U.p.MgCa <- selectData(CDH46_Up,var.name = "Mg/Ca",meas.table.num = 2)
CDH46.U.p.MgLi <- selectData(CDH46_Up,var.name = "Mg/Li",meas.table.num = 2)
CDH46.U.p.CdCa <- selectData(CDH46_Up,var.name = "Cd/Ca",meas.table.num = 2)
CDH46.U.p.BCa <- selectData(CDH46_Up,var.name = "B/Ca",meas.table.num = 2)
CDH46.U.p.UCa <- selectData(CDH46_Up,var.name = "U/Ca",meas.table.num = 2)
CDH46.U.p.MnCa <- selectData(CDH46_Up,var.name = "Mn/Ca",meas.table.num = 2)
CDH46.U.p.FeCa <- selectData(CDH46_Up,var.name = "Fe/Ca",meas.table.num = 2)
CDH46.U.p.AlCa <- selectData(CDH46_Up,var.name = "Al/Ca",meas.table.num = 2)
CDH46.U.p.BWT <- selectData(CDH46_Up,var.name = "BWT",meas.table.num = 2)
CDH46.U.p.CdW <- selectData(CDH46_Up,var.name = "CdW",meas.table.num = 2)

CDH46.C.p.depth <- selectData(CDH46_Cp,var.name = "Depth",meas.table.num = 3)
CDH46.C.p.LiCa <- selectData(CDH46_Cp,var.name = "Li/Ca",meas.table.num = 3)
CDH46.C.p.MgCa <- selectData(CDH46_Cp,var.name = "Mg/Ca",meas.table.num = 3)
CDH46.C.p.MgLi <- selectData(CDH46_Cp,var.name = "Mg/Li",meas.table.num = 3)
CDH46.C.p.CdCa <- selectData(CDH46_Cp,var.name = "Cd/Ca",meas.table.num = 3)
CDH46.C.p.BCa <- selectData(CDH46_Cp,var.name = "B/Ca",meas.table.num = 3)
CDH46.C.p.UCa <- selectData(CDH46_Cp,var.name = "U/Ca",meas.table.num = 3)
CDH46.C.p.MnCa <- selectData(CDH46_Cp,var.name = "Mn/Ca",meas.table.num = 3)
CDH46.C.p.FeCa <- selectData(CDH46_Cp,var.name = "Fe/Ca",meas.table.num = 3)
CDH46.C.p.AlCa <- selectData(CDH46_Cp,var.name = "Al/Ca",meas.table.num = 3)
CDH46.C.p.BWT <- selectData(CDH46_Cp,var.name = "BWT",meas.table.num = 3)
CDH46.C.p.CdW <- selectData(CDH46_Cp,var.name = "CdW",meas.table.num = 3)
CDH46.C.p.dCO3 <- selectData(CDH46_Cp,var.name = "dCO3",meas.table.num = 3)


CDH46.I.so.depth <- selectData(CDH46_Iso,var.name = "Depth",meas.table.num = 4)
CDH46.I.so.d13C <- selectData(CDH46_Iso,var.name = "d13C",meas.table.num = 4)
CDH46.I.so.d18O <- selectData(CDH46_Iso,var.name = "d18O",meas.table.num = 4)



# export data with x as median Bacon age, y as raw data

CDH46.H.e.raw <- data.frame(CDH46.H.e.depth$values,
                            apply(CDH46.H.e.ae$values, 1, median),
                            CDH46.H.e.LiCa$values,
                            CDH46.H.e.MgCa$values,
                            CDH46.H.e.MgLi$values,
                            CDH46.H.e.CdCa$values,
                            CDH46.H.e.BCa$values,
                            CDH46.H.e.UCa$values,
                            CDH46.H.e.MnCa$values,
                            CDH46.H.e.FeCa$values,
                            CDH46.H.e.AlCa$values,
                            CDH46.H.e.BWT$values,
                            CDH46.H.e.CdW$values
                            )

CDH46.H.e.raw <- rename(CDH46.H.e.raw,
                        c("Depth" = "CDH46.H.e.depth.values",
                          "median_age" = "apply.CDH46.H.e.ae.values..1..median.",
                          "LiCa" = "CDH46.H.e.LiCa.values",
                          "MgCa" = "CDH46.H.e.MgCa.values",
                          "MgLi" = "CDH46.H.e.MgLi.values",
                          "CdCa" = "CDH46.H.e.CdCa.values",
                          "BCa" = "CDH46.H.e.BCa.values",
                          "UCa" = "CDH46.H.e.UCa.values",
                          "MnCa" = "CDH46.H.e.MnCa.values",
                          "FeCa" = "CDH46.H.e.FeCa.values",
                          "AlCa" = "CDH46.H.e.AlCa.values",
                          "BWT" = "CDH46.H.e.BWT.values",
                          "CdW" = "CDH46.H.e.CdW.values"
                          ))

write.csv(CDH46.H.e.raw, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\CDH46.H.e.raw.Oppo2023.csv",row.names = FALSE)


CDH46.U.p.raw <- data.frame(CDH46.U.p.depth$values,
                            apply(CDH46.U.p.ae$values, 1, median),
                            CDH46.U.p.LiCa$values,
                            CDH46.U.p.MgCa$values,
                            CDH46.U.p.MgLi$values,
                            CDH46.U.p.CdCa$values,
                            CDH46.U.p.BCa$values,
                            CDH46.U.p.UCa$values,
                            CDH46.U.p.MnCa$values,
                            CDH46.U.p.FeCa$values,
                            CDH46.U.p.AlCa$values,
                            CDH46.U.p.BWT$values,
                            CDH46.U.p.CdW$values
)

CDH46.U.p.raw <- rename(CDH46.U.p.raw,
                        c("Depth" = "CDH46.U.p.depth.values",
                          "median_age" = "apply.CDH46.U.p.ae.values..1..median.",
                          "LiCa" = "CDH46.U.p.LiCa.values",
                          "MgCa" = "CDH46.U.p.MgCa.values",
                          "MgLi" = "CDH46.U.p.MgLi.values",
                          "CdCa" = "CDH46.U.p.CdCa.values",
                          "BCa" = "CDH46.U.p.BCa.values",
                          "UCa" = "CDH46.U.p.UCa.values",
                          "MnCa" = "CDH46.U.p.MnCa.values",
                          "FeCa" = "CDH46.U.p.FeCa.values",
                          "AlCa" = "CDH46.U.p.AlCa.values",
                          "BWT" = "CDH46.U.p.BWT.values",
                          "CdW" = "CDH46.U.p.CdW.values"
                        ))

write.csv(CDH46.U.p.raw, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\CDH46.U.p.raw.Oppo2023.csv",row.names = FALSE)

CDH46.C.p.raw <- data.frame(CDH46.C.p.depth$values,
                            apply(CDH46.C.p.ae$values, 1, median),
                            CDH46.C.p.LiCa$values,
                            CDH46.C.p.MgCa$values,
                            CDH46.C.p.MgLi$values,
                            CDH46.C.p.CdCa$values,
                            CDH46.C.p.BCa$values,
                            CDH46.C.p.UCa$values,
                            CDH46.C.p.MnCa$values,
                            CDH46.C.p.FeCa$values,
                            CDH46.C.p.AlCa$values,
                            CDH46.C.p.BWT$values,
                            CDH46.C.p.CdW$values,
                            CDH46.C.p.dCO3$values
)

CDH46.C.p.raw <- rename(CDH46.C.p.raw,
                        c("Depth" = "CDH46.C.p.depth.values",
                          "median_age" = "apply.CDH46.C.p.ae.values..1..median.",
                          "LiCa" = "CDH46.C.p.LiCa.values",
                          "MgCa" = "CDH46.C.p.MgCa.values",
                          "MgLi" = "CDH46.C.p.MgLi.values",
                          "CdCa" = "CDH46.C.p.CdCa.values",
                          "BCa" = "CDH46.C.p.BCa.values",
                          "UCa" = "CDH46.C.p.UCa.values",
                          "MnCa" = "CDH46.C.p.MnCa.values",
                          "FeCa" = "CDH46.C.p.FeCa.values",
                          "AlCa" = "CDH46.C.p.AlCa.values",
                          "BWT" = "CDH46.C.p.BWT.values",
                          "CdW" = "CDH46.C.p.CdW.values",
                          "dCO3" = "CDH46.C.p.dCO3.values"
                        ))

write.csv(CDH46.C.p.raw, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\CDH46.C.p.raw.Oppo2023.csv",row.names = FALSE)

CDH46.I.so.raw <- data.frame(CDH46.I.so.depth$values,
                             apply(CDH46.I.so.ae$values, 1, median),
                             CDH46.I.so.d13C$values,
                             CDH46.I.so.d18O$values)

CDH46.I.so.raw <- rename(CDH46.I.so.raw,
                         c("Depth" = "CDH46.I.so.depth.values",
                           "median_age" = "apply.CDH46.I.so.ae.values..1..median.",
                           "d13C" = "CDH46.I.so.d13C.values",
                           "d18O" = "CDH46.I.so.d18O.values"
                         ))

write.csv(CDH46.I.so.raw, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\CDH46.I.so.raw.Oppo2023.csv",row.names = FALSE)

#ribbon

CDH46.H.e.BWT.rec05 <- plotTimeseriesEnsRibbons(X = CDH46.H.e.ae,Y = CDH46.H.e.BWT, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.H.e.BWT.rec05 <- rename(CDH46.H.e.BWT.rec05,c("median_BWT" = "0.5"))

CDH46.H.e.BWT.rec025 <- plotTimeseriesEnsRibbons(X = CDH46.H.e.ae,Y = CDH46.H.e.BWT, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.H.e.BWT.rec025 <- rename(CDH46.H.e.BWT.rec025,c("lower025_BWT" = "0.25"))

CDH46.H.e.BWT.rec075 <- plotTimeseriesEnsRibbons(X = CDH46.H.e.ae,Y = CDH46.H.e.BWT, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.H.e.BWT.rec075 <- rename(CDH46.H.e.BWT.rec075,c("upper075_BWT" = "0.75"))

CDH46.H.e.BWT.rec0025 <- plotTimeseriesEnsRibbons(X = CDH46.H.e.ae,Y = CDH46.H.e.BWT, probs = 0.025, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.H.e.BWT.rec0025 <- rename(CDH46.H.e.BWT.rec0025,c("lower0025_BWT" = "0.025"))

CDH46.H.e.BWT.rec0975 <- plotTimeseriesEnsRibbons(X = CDH46.H.e.ae,Y = CDH46.H.e.BWT, probs = 0.975, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.H.e.BWT.rec0975 <- rename(CDH46.H.e.BWT.rec0975,c("upper0975_BWT" = "0.975"))

#CdW
CDH46.H.e.CdW.rec05 <- plotTimeseriesEnsRibbons(X = CDH46.H.e.ae,Y = CDH46.H.e.CdW, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.H.e.CdW.rec05 <- rename(CDH46.H.e.CdW.rec05,c("median_CdW" = "0.5"))

CDH46.H.e.CdW.rec025 <- plotTimeseriesEnsRibbons(X = CDH46.H.e.ae,Y = CDH46.H.e.CdW, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.H.e.CdW.rec025 <- rename(CDH46.H.e.CdW.rec025,c("lower025_CdW" = "0.25"))

CDH46.H.e.CdW.rec075 <- plotTimeseriesEnsRibbons(X = CDH46.H.e.ae,Y = CDH46.H.e.CdW, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.H.e.CdW.rec075 <- rename(CDH46.H.e.CdW.rec075,c("upper075_CdW" = "0.75"))

CDH46.H.e.CdW.rec0025 <- plotTimeseriesEnsRibbons(X = CDH46.H.e.ae,Y = CDH46.H.e.CdW, probs = 0.025, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.H.e.CdW.rec0025 <- rename(CDH46.H.e.CdW.rec0025,c("lower0025_CdW" = "0.025"))

CDH46.H.e.CdW.rec0975 <- plotTimeseriesEnsRibbons(X = CDH46.H.e.ae,Y = CDH46.H.e.CdW, probs = 0.975, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.H.e.CdW.rec0975 <- rename(CDH46.H.e.CdW.rec0975,c("upper0975_CdW" = "0.975"))

CDH46.H.e.rec <- data.frame(CDH46.H.e.BWT.rec05$ages,
                            CDH46.H.e.BWT.rec05$median_BWT,
                            CDH46.H.e.BWT.rec025$lower025_BWT,
                            CDH46.H.e.BWT.rec075$upper075_BWT,
                            CDH46.H.e.BWT.rec0025$lower0025_BWT,
                            CDH46.H.e.BWT.rec0975$upper0975_BWT,
                            CDH46.H.e.CdW.rec05$median_CdW,
                            CDH46.H.e.CdW.rec025$lower025_CdW,
                            CDH46.H.e.CdW.rec075$upper075_CdW,
                            CDH46.H.e.CdW.rec0025$lower0025_CdW,
                            CDH46.H.e.CdW.rec0975$upper0975_CdW
)

CDH46.H.e.rec <- rename(CDH46.H.e.rec,c("age" = "CDH46.H.e.BWT.rec05.ages",
                                        "median_BWT" = "CDH46.H.e.BWT.rec05.median_BWT",
                                        "lower025_BWT" = "CDH46.H.e.BWT.rec025.lower025_BWT",
                                        "upper075_BWT" = "CDH46.H.e.BWT.rec075.upper075_BWT",
                                        "lower0025_BWT" = "CDH46.H.e.BWT.rec0025.lower0025_BWT",
                                        "upper0975_BWT" = "CDH46.H.e.BWT.rec0975.upper0975_BWT",
                                        "median_CdW" = "CDH46.H.e.CdW.rec05.median_CdW",
                                        "lower025_CdW" = "CDH46.H.e.CdW.rec025.lower025_CdW",
                                        "upper075_CdW" = "CDH46.H.e.CdW.rec075.upper075_CdW",
                                        "lower0025_CdW" = "CDH46.H.e.CdW.rec0025.lower0025_CdW",
                                        "upper0975_CdW" = "CDH46.H.e.CdW.rec0975.upper0975_CdW"
))

write.csv(CDH46.H.e.rec, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table_noflags\\CDH46.H.e.rib.Oppo2023.csv",row.names = FALSE)




#Ribbon
CDH46.C.p.dCO3.rec05 <- plotTimeseriesEnsRibbons(X = CDH46.C.p.ae,Y = CDH46.C.p.dCO3, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.C.p.dCO3.rec05 <- rename(CDH46.C.p.dCO3.rec05,c("median_dCO3" = "0.5"))

CDH46.C.p.dCO3.rec025 <- plotTimeseriesEnsRibbons(X = CDH46.C.p.ae,Y = CDH46.C.p.dCO3, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.C.p.dCO3.rec025 <- rename(CDH46.C.p.dCO3.rec025,c("lower025_dCO3" = "0.25"))

CDH46.C.p.dCO3.rec075 <- plotTimeseriesEnsRibbons(X = CDH46.C.p.ae,Y = CDH46.C.p.dCO3, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.C.p.dCO3.rec075 <- rename(CDH46.C.p.dCO3.rec075,c("upper075_dCO3" = "0.75"))

CDH46.C.p.dCO3.rec0025 <- plotTimeseriesEnsRibbons(X = CDH46.C.p.ae,Y = CDH46.C.p.dCO3, probs = 0.025, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.C.p.dCO3.rec0025 <- rename(CDH46.C.p.dCO3.rec0025,c("lower0025_dCO3" = "0.025"))

CDH46.C.p.dCO3.rec0975 <- plotTimeseriesEnsRibbons(X = CDH46.C.p.ae,Y = CDH46.C.p.dCO3, probs = 0.975, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.C.p.dCO3.rec0975 <- rename(CDH46.C.p.dCO3.rec0975,c("upper0975_dCO3" = "0.975"))

#CdW
CDH46.C.p.CdW.rec05 <- plotTimeseriesEnsRibbons(X = CDH46.C.p.ae,Y = CDH46.C.p.CdW, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.C.p.CdW.rec05 <- rename(CDH46.C.p.CdW.rec05,c("median_CdW" = "0.5"))

CDH46.C.p.CdW.rec025 <- plotTimeseriesEnsRibbons(X = CDH46.C.p.ae,Y = CDH46.C.p.CdW, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.C.p.CdW.rec025 <- rename(CDH46.C.p.CdW.rec025,c("lower025_CdW" = "0.25"))

CDH46.C.p.CdW.rec075 <- plotTimeseriesEnsRibbons(X = CDH46.C.p.ae,Y = CDH46.C.p.CdW, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.C.p.CdW.rec075 <- rename(CDH46.C.p.CdW.rec075,c("upper075_CdW" = "0.75"))

CDH46.C.p.CdW.rec0025 <- plotTimeseriesEnsRibbons(X = CDH46.C.p.ae,Y = CDH46.C.p.CdW, probs = 0.025, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.C.p.CdW.rec0025 <- rename(CDH46.C.p.CdW.rec0025,c("lower0025_CdW" = "0.025"))

CDH46.C.p.CdW.rec0975 <- plotTimeseriesEnsRibbons(X = CDH46.C.p.ae,Y = CDH46.C.p.CdW, probs = 0.975, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.C.p.CdW.rec0975 <- rename(CDH46.C.p.CdW.rec0975,c("upper0975_CdW" = "0.975"))


#d13C
CDH46.I.so.d13C.rec05 <- plotTimeseriesEnsRibbons(X = CDH46.I.so.ae,Y = CDH46.I.so.d13C, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.I.so.d13C.rec05 <- rename(CDH46.I.so.d13C.rec05,c("median_d13C" = "0.5"))

CDH46.I.so.d13C.rec025 <- plotTimeseriesEnsRibbons(X = CDH46.I.so.ae,Y = CDH46.I.so.d13C, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.I.so.d13C.rec025 <- rename(CDH46.I.so.d13C.rec025,c("lower025_d13C" = "0.25"))

CDH46.I.so.d13C.rec075 <- plotTimeseriesEnsRibbons(X = CDH46.I.so.ae,Y = CDH46.I.so.d13C, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.I.so.d13C.rec075 <- rename(CDH46.I.so.d13C.rec075,c("upper075_d13C" = "0.75"))

CDH46.I.so.d13C.rec0025 <- plotTimeseriesEnsRibbons(X = CDH46.I.so.ae,Y = CDH46.I.so.d13C, probs = 0.025, limit.outliers.x = 0.05, export.quantiles = TRUE)
CDH46.I.so.d13C.rec0025 <- rename(CDH46.I.so.d13C.rec0025,c("lower0025_d13C" = "0.025"))

CDH46.I.so.d13C.rec0975 <- plotTimeseriesEnsRibbons(X = CDH46.I.so.ae,Y = CDH46.I.so.d13C, probs = 0.975, limit.outliers.x = 0.05, export.quantiles = TRUE)
CDH46.I.so.d13C.rec0975 <- rename(CDH46.I.so.d13C.rec0975,c("upper0975_d13C" = "0.975"))

#d18O
CDH46.I.so.d18O.rec05 <- plotTimeseriesEnsRibbons(X = CDH46.I.so.ae,Y = CDH46.I.so.d18O, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.I.so.d18O.rec05 <- rename(CDH46.I.so.d18O.rec05,c("median_d18O" = "0.5"))

CDH46.I.so.d18O.rec025 <- plotTimeseriesEnsRibbons(X = CDH46.I.so.ae,Y = CDH46.I.so.d18O, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.I.so.d18O.rec025 <- rename(CDH46.I.so.d18O.rec025,c("lower025_d18O" = "0.25"))

CDH46.I.so.d18O.rec075 <- plotTimeseriesEnsRibbons(X = CDH46.I.so.ae,Y = CDH46.I.so.d18O, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
CDH46.I.so.d18O.rec075 <- rename(CDH46.I.so.d18O.rec075,c("upper075_d18O" = "0.75"))

CDH46.I.so.d18O.rec0025 <- plotTimeseriesEnsRibbons(X = CDH46.I.so.ae,Y = CDH46.I.so.d18O, probs = 0.025, limit.outliers.x = 0.05, export.quantiles = TRUE)
CDH46.I.so.d18O.rec0025 <- rename(CDH46.I.so.d18O.rec0025,c("lower0025_d18O" = "0.025"))

CDH46.I.so.d18O.rec0975 <- plotTimeseriesEnsRibbons(X = CDH46.I.so.ae,Y = CDH46.I.so.d18O, probs = 0.975, limit.outliers.x = 0.05, export.quantiles = TRUE)
CDH46.I.so.d18O.rec0975 <- rename(CDH46.I.so.d18O.rec0975,c("upper0975_d18O" = "0.975"))


CDH46.C.p.rec <- data.frame(CDH46.C.p.dCO3.rec05$ages,
                            CDH46.C.p.dCO3.rec05$median_dCO3,
                            CDH46.C.p.dCO3.rec025$lower025_dCO3,
                            CDH46.C.p.dCO3.rec075$upper075_dCO3,
                            CDH46.C.p.dCO3.rec0025$lower0025_dCO3,
                            CDH46.C.p.dCO3.rec0975$upper0975_dCO3,
                            CDH46.C.p.CdW.rec05$median_CdW,
                            CDH46.C.p.CdW.rec025$lower025_CdW,
                            CDH46.C.p.CdW.rec075$upper075_CdW,
                            CDH46.C.p.CdW.rec0025$lower0025_CdW,
                            CDH46.C.p.CdW.rec0975$upper0975_CdW
)

CDH46.I.so.rec <- data.frame(CDH46.I.so.d13C.rec05$ages,
                             CDH46.I.so.d13C.rec05$median_d13C,
                             CDH46.I.so.d13C.rec025$lower025_d13C,
                             CDH46.I.so.d13C.rec075$upper075_d13C,
                             CDH46.I.so.d13C.rec0025$lower0025_d13C,
                             CDH46.I.so.d13C.rec0975$upper0975_d13C,
                             CDH46.I.so.d18O.rec05$median_d18O,
                             CDH46.I.so.d18O.rec025$lower025_d18O,
                             CDH46.I.so.d18O.rec075$upper075_d18O,
                             CDH46.I.so.d18O.rec0025$lower0025_d18O,
                             CDH46.I.so.d18O.rec0975$upper0975_d18O)

CDH46.C.p.rec <- rename(CDH46.C.p.rec,c("age" = "CDH46.C.p.dCO3.rec05.ages",
                                        "median_dCO3" = "CDH46.C.p.dCO3.rec05.median_dCO3",
                                        "lower025_dCO3" = "CDH46.C.p.dCO3.rec025.lower025_dCO3",
                                        "upper075_dCO3" = "CDH46.C.p.dCO3.rec075.upper075_dCO3",
                                        "lower0025_dCO3" = "CDH46.C.p.dCO3.rec0025.lower0025_dCO3",
                                        "upper0975_dCO3" = "CDH46.C.p.dCO3.rec0975.upper0975_dCO3",
                                        "median_CdW" = "CDH46.C.p.CdW.rec05.median_CdW",
                                        "lower025_CdW" = "CDH46.C.p.CdW.rec025.lower025_CdW",
                                        "upper075_CdW" = "CDH46.C.p.CdW.rec075.upper075_CdW",
                                        "lower0025_CdW" = "CDH46.C.p.CdW.rec0025.lower0025_CdW",
                                        "upper0975_CdW" = "CDH46.C.p.CdW.rec0975.upper0975_CdW"
))

CDH46.I.so.rec <- rename(CDH46.I.so.rec,c("age" = "CDH46.I.so.d13C.rec05.ages",
                                          "median_d13C" = "CDH46.I.so.d13C.rec05.median_d13C",
                                          "lower025_d13C" = "CDH46.I.so.d13C.rec025.lower025_d13C",
                                          "upper075_d13C" = "CDH46.I.so.d13C.rec075.upper075_d13C",
                                          "lower0025_d13C" = "CDH46.I.so.d13C.rec0025.lower0025_d13C",
                                          "upper0975_d13C" = "CDH46.I.so.d13C.rec0975.upper0975_d13C",
                                          "median_d18O" = "CDH46.I.so.d18O.rec05.median_d18O",
                                          "lower025_d18O" = "CDH46.I.so.d18O.rec025.lower025_d18O",
                                          "upper075_d18O" = "CDH46.I.so.d18O.rec075.upper075_d18O",
                                          "lower0025_d18O" = "CDH46.I.so.d18O.rec0025.lower0025_d18O",
                                          "upper0975_d18O" = "CDH46.I.so.d18O.rec0975.upper0975_d18O"))

write.csv(CDH46.C.p.rec, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table_noflags\\CDH46.C.p.rib.Oppo2023.csv",row.names = FALSE)

write.csv(CDH46.I.so.rec, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table_noflags\\CDH46.I.so.rib.Oppo2023.csv",row.names = FALSE)

#Example plot of d18O
CDH46.I.so.d18O.plot1 <- plotTimeseriesEnsRibbons(X = CDH46.I.so.ae,
                                                 Y = CDH46.I.so.d18O,
                                                 probs = c(0.001, 0.25, 0.5, 0.75, 0.999),
                                                 n.bins = 1000,
                                                 alp = 0.2, 
                                                 color.low = "Blue",
                                                 color.high = "Blue",
                                                 color.line = "Blue",
                                                 limit.outliers.x = 0.025)+
  scale_x_continuous(limits = c(0,25000),
                     breaks = seq(0,25000,2000))+
  ylim(c(4.5,2))+
  ggtitle("CDH46 C.p. d18O")

CDH46.I.so.d18O.plot2 <- plotScatterEns(X = apply(CDH46.I.so.ae$values, 1, median), Y = CDH46.I.so.d18O$values, alp = 1, add.to.plot = CDH46.I.so.d18O.plot1)

print(CDH46.I.so.d18O.plot2)

CDH46.I.so.d18O.plot3 <- plotTimeseriesEnsLines(X = CDH46.I.so.ae,Y = CDH46.I.so.d18O,alp = 0.1,n.ens.plot = 10,color = "red",add.to.plot = CDH46.I.so.d18O.plot2)+ggtitle("CDH46 C.p. d18O")+
  scale_x_continuous(limits = c(0,25000),
                     breaks = seq(0,25000,2000))+
  ylim(c(4.5,2))+
  ggtitle("CDH46 C.p.. d18O")

print(CDH46.I.so.d18O.plot3)

