library(geoChronR)
library(magrittr)
library(ggplot2)
library(lipdR)

library(plyr)
library(dplyr)
library(tidyr)
library(patchwork)



#GGC90, Umling 2019
GGC90 <- lipdR::readLipd("D:/WHOI/Research/Holocene_AMOC/geoChronR/LiPD/KNR159-5-90GGC.Umling.2019.lpd")

GGC90 = runBacon(GGC90,
                 chron.num = 1,
                 model.num = 1,
                 meas.table.num = NA,
                 bacon.dir = "D:/WHOI/Research/Holocene_AMOC/geoChronR/Bacon_runs",
                 lab.id.var = 'labid',
                 age.14c.var = 'age14c', 
                 age.14c.uncertainty.var = 'age14cunc', 
                 age.var = 'age', 
                 age.uncertainty.var = 'ageunc',
                 depth.var = 'depth', 
                 reservoir.age.14c.var = 'dR',
                 reservoir.age.14c.uncertainty.var = 'dSTD', 
                 rejected.ages.var = NULL,
                 cc = 2, #all 14C dates use marine20
                 bacon.thick = 5,
                 bacon.acc.mean = 20,
                 plot.pdf = FALSE,
                 overwrite = TRUE)

#map the model ensemble values to a measurement table in paleoData

GGC90_He <- mapAgeEnsembleToPaleoData(GGC90,age.var = "ageEnsemble",paleo.meas.table.num = 1)

#Select age

GGC90.H.e.ae <- selectData(GGC90_He,var.name = "ageEnsemble",meas.table.num = 1)


#select variables
GGC90.H.e.depth <- selectData(GGC90_He,var.name = "Depth",meas.table.num = 1)
GGC90.H.e.LiCa <- selectData(GGC90_He,var.name = "Li/Ca",meas.table.num = 1)
GGC90.H.e.MgCa <- selectData(GGC90_He,var.name = "Mg/Ca",meas.table.num = 1)
GGC90.H.e.MgLi <- selectData(GGC90_He,var.name = "Mg/Li",meas.table.num = 1)
GGC90.H.e.CdCa <- selectData(GGC90_He,var.name = "Cd/Ca",meas.table.num = 1)
GGC90.H.e.BWT <- selectData(GGC90_He,var.name = "BWT",meas.table.num = 1)
GGC90.H.e.CdW <- selectData(GGC90_He,var.name = "CdW",meas.table.num = 1)



# export data with x as median Bacon age, y as raw data

GGC90.H.e.raw <- data.frame(GGC90.H.e.depth$values,
                            apply(GGC90.H.e.ae$values, 1, median),
                            GGC90.H.e.LiCa$values,
                            GGC90.H.e.MgCa$values,
                            GGC90.H.e.MgLi$values,
                            GGC90.H.e.CdCa$values,
                            GGC90.H.e.BWT$values,
                            GGC90.H.e.CdW$values)

GGC90.H.e.raw <- rename(GGC90.H.e.raw,
                        c("Depth" = "GGC90.H.e.depth.values",
                          "median_age" = "apply.GGC90.H.e.ae.values..1..median.",
                          "LiCa" = "GGC90.H.e.LiCa.values",
                          "MgCa" = "GGC90.H.e.MgCa.values",
                          "MgLi" = "GGC90.H.e.MgLi.values",
                          "CdCa" = "GGC90.H.e.CdCa.values",
                          "BWT" = "GGC90.H.e.BWT.values",
                          "CdW" = "GGC90.H.e.CdW.values"))

write.csv(GGC90.H.e.raw, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\GGC90.H.e.raw.csv",row.names = FALSE)

BWT.plot <- GGC90.H.e.raw %>%
  ggplot()+
  geom_point(aes(x = median_age/1000, y = BWT))+
  geom_line(aes(x = median_age/1000, y = BWT))+
  theme_bw()+
  theme(axis.line = element_line(color='black'),
        plot.background = element_blank(),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank())+
  #theme(legend.position="none")+
  ggtitle("BWT")

print(BWT.plot)

CdW.plot <- GGC90.H.e.raw %>%
  ggplot()+
  geom_point(aes(x = median_age/1000, y = CdW))+
  geom_line(aes(x = median_age/1000, y = CdW))+
  theme_bw()+
  theme(axis.line = element_line(color='black'),
        plot.background = element_blank(),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank())+
  #theme(legend.position="none")+
  ggtitle("CdW")

print(CdW.plot)


## Extract median ensemble
#BWT
GGC90.H.e.BWT.rec05 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,Y = GGC90.H.e.BWT, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90.H.e.BWT.rec05 <- rename(GGC90.H.e.BWT.rec05,c("median_BWT" = "0.5"))

GGC90.H.e.BWT.rec025 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,Y = GGC90.H.e.BWT, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90.H.e.BWT.rec025 <- rename(GGC90.H.e.BWT.rec025,c("lower025_BWT" = "0.25"))

GGC90.H.e.BWT.rec075 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,Y = GGC90.H.e.BWT, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90.H.e.BWT.rec075 <- rename(GGC90.H.e.BWT.rec075,c("upper075_BWT" = "0.75"))

GGC90.H.e.BWT.rec0025 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,Y = GGC90.H.e.BWT, probs = 0.025, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90.H.e.BWT.rec0025 <- rename(GGC90.H.e.BWT.rec0025,c("lower0025_BWT" = "0.025"))

GGC90.H.e.BWT.rec0975 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,Y = GGC90.H.e.BWT, probs = 0.975, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90.H.e.BWT.rec0975 <- rename(GGC90.H.e.BWT.rec0975,c("upper0975_BWT" = "0.975"))

#CdW
GGC90.H.e.CdW.rec05 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,Y = GGC90.H.e.CdW, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90.H.e.CdW.rec05 <- rename(GGC90.H.e.CdW.rec05,c("median_CdW" = "0.5"))

GGC90.H.e.CdW.rec025 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,Y = GGC90.H.e.CdW, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90.H.e.CdW.rec025 <- rename(GGC90.H.e.CdW.rec025,c("lower025_CdW" = "0.25"))

GGC90.H.e.CdW.rec075 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,Y = GGC90.H.e.CdW, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90.H.e.CdW.rec075 <- rename(GGC90.H.e.CdW.rec075,c("upper075_CdW" = "0.75"))

GGC90.H.e.CdW.rec0025 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,Y = GGC90.H.e.CdW, probs = 0.025, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90.H.e.CdW.rec0025 <- rename(GGC90.H.e.CdW.rec0025,c("lower0025_CdW" = "0.025"))

GGC90.H.e.CdW.rec0975 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,Y = GGC90.H.e.CdW, probs = 0.975, limit.outliers.x = 0.025, export.quantiles = TRUE)
GGC90.H.e.CdW.rec0975 <- rename(GGC90.H.e.CdW.rec0975,c("upper0975_CdW" = "0.975"))


GGC90.H.e.rec <- data.frame(GGC90.H.e.BWT.rec05$ages,
                            GGC90.H.e.BWT.rec05$median_BWT,
                            GGC90.H.e.BWT.rec025$lower025_BWT,
                            GGC90.H.e.BWT.rec075$upper075_BWT,
                            GGC90.H.e.BWT.rec0025$lower0025_BWT,
                            GGC90.H.e.BWT.rec0975$upper0975_BWT,
                            GGC90.H.e.CdW.rec05$median_CdW,
                            GGC90.H.e.CdW.rec025$lower025_CdW,
                            GGC90.H.e.CdW.rec075$upper075_CdW,
                            GGC90.H.e.CdW.rec0025$lower0025_CdW,
                            GGC90.H.e.CdW.rec0975$upper0975_CdW)

GGC90.H.e.rec <- rename(GGC90.H.e.rec,c("age" = "GGC90.H.e.BWT.rec05.ages",
                                        "median_BWT" = "GGC90.H.e.BWT.rec05.median_BWT",
                                        "lower025_BWT" = "GGC90.H.e.BWT.rec025.lower025_BWT",
                                        "upper075_BWT" = "GGC90.H.e.BWT.rec075.upper075_BWT",
                                        "lower005_BWT" = "GGC90.H.e.BWT.rec0025.lower0025_BWT",
                                        "upper095_BWT" = "GGC90.H.e.BWT.rec0975.upper0975_BWT",
                                        "median_CdW" = "GGC90.H.e.CdW.rec05.median_CdW",
                                        "lower025_CdW" = "GGC90.H.e.CdW.rec025.lower025_CdW",
                                        "upper075_CdW" = "GGC90.H.e.CdW.rec075.upper075_CdW",
                                        "lower005_CdW" = "GGC90.H.e.CdW.rec0025.lower0025_CdW",
                                        "upper095_CdW" = "GGC90.H.e.CdW.rec0975.upper0975_CdW"))

write.csv(GGC90.H.e.rec, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\GGC90.H.e.rib.csv",row.names = FALSE)

#Plot ribbons and raw data
GGC90.H.e.BWT.plot1 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,
                                                 Y = GGC90.H.e.BWT,
                                                 probs = c(0.025, 0.25, 0.5, 0.75, 0.975),
                                                 n.bins = 209,
                                                 alp = 0.2, 
                                                 color.low = "Blue",
                                                 color.high = "Blue",
                                                 color.line = "Blue"
                                                )+
  xlim(c(0,35000))+
  ylim(c(0,15))+
  ggtitle("GGC90 H.e. BWT")

GGC90.H.e.BWT.plot2 <- plotScatterEns(X = apply(GGC90.H.e.ae$values, 1, median), Y = GGC90.H.e.BWT$values, alp = 1, add.to.plot = GGC90.H.e.BWT.plot1)

print(GGC90.H.e.BWT.plot2)

GGC90.H.e.CdW.plot1 <- plotTimeseriesEnsRibbons(X = GGC90.H.e.ae,
                                                Y = GGC90.H.e.CdW,
                                                probs = c(0.025, 0.25, 0.5, 0.75, 0.975),
                                                n.bins = 209,
                                                alp = 0.2, 
                                                color.low = "Blue",
                                                color.high = "Blue",
                                                color.line = "Blue"
)+
  xlim(c(0,35000))+
  ylim(c(0,0.8))+
  ggtitle("GGC90 H.e. CdW")

GGC90.H.e.CdW.plot2 <- plotScatterEns(X = apply(GGC90.H.e.ae$values, 1, median), Y = GGC90.H.e.CdW$values, alp = 1, add.to.plot = GGC90.H.e.CdW.plot1)

print(GGC90.H.e.CdW.plot2)
