library(geoChronR)
library(magrittr)
library(ggplot2)
library(lipdR)

library(plyr)
library(dplyr)
library(tidyr)
library(patchwork)



#JPC26, Valley 2019
JPC26 <- lipdR::readLipd("D:/WHOI/Research/Holocene_AMOC/geoChronR/LiPD/KNR166-2-26JPC.Valley.2019.lpd")

JPC26 = runBacon(JPC26,
                 chron.num = 1,
                 model.num = 1,
                 meas.table.num = NA,
                 bacon.dir = "D:/WHOI/Research/Holocene_AMOC/geoChronR/Bacon_runs",
                 lab.id.var = 'labid',
                 age.14c.var = 'age14c', 
                 age.14c.uncertainty.var = 'age14cunc', 
                 age.var = 'age', 
                 age.uncertainty.var = 'ageunc',
                 depth.var = 'depth', 
                 reservoir.age.14c.var = 'dR',
                 reservoir.age.14c.uncertainty.var = 'dSTD', 
                 rejected.ages.var = NULL,
                 cc = 2, #all 14C dates use marine20
                 bacon.thick = 5,
                 bacon.acc.mean = 20,
                 plot.pdf = FALSE,
                 overwrite = TRUE)

#map the model ensemble values to a measurement table in paleoData

JPC26_He <- mapAgeEnsembleToPaleoData(JPC26,age.var = "ageEnsemble",paleo.meas.table.num = 1)
JPC26_Iso <- mapAgeEnsembleToPaleoData(JPC26,age.var = "ageEnsemble",paleo.meas.table.num = 2)


#Select age

JPC26.H.e.ae <- selectData(JPC26_He,var.name = "ageEnsemble",meas.table.num = 1)
JPC26.I.so.ae <- selectData(JPC26_Iso,var.name = "ageEnsemble",meas.table.num = 2)


#select variables
JPC26.H.e.depth <- selectData(JPC26_He,var.name = "Depth",meas.table.num = 1)
JPC26.H.e.LiCa <- selectData(JPC26_He,var.name = "Li/Ca",meas.table.num = 1)
JPC26.H.e.MgCa <- selectData(JPC26_He,var.name = "Mg/Ca",meas.table.num = 1)
JPC26.H.e.MgLi <- selectData(JPC26_He,var.name = "Mg/Li",meas.table.num = 1)
JPC26.H.e.CdCa <- selectData(JPC26_He,var.name = "Cd/Ca",meas.table.num = 1)
JPC26.H.e.BWT <- selectData(JPC26_He,var.name = "BWT",meas.table.num = 1)
JPC26.H.e.CdW <- selectData(JPC26_He,var.name = "CdW",meas.table.num = 1)

JPC26.I.so.depth <- selectData(JPC26_Iso,var.name = "Depth",meas.table.num = 2)
JPC26.I.so.d13C <- selectData(JPC26_Iso,var.name = "d13C",meas.table.num = 2)
JPC26.I.so.d18O <- selectData(JPC26_Iso,var.name = "d18O",meas.table.num = 2)

# export data with x as median Bacon age, y as raw data

JPC26.H.e.raw <- data.frame(JPC26.H.e.depth$values,
                            apply(JPC26.H.e.ae$values, 1, median),
                            JPC26.H.e.LiCa$values,
                            JPC26.H.e.MgCa$values,
                            JPC26.H.e.MgLi$values,
                            JPC26.H.e.CdCa$values,
                            JPC26.H.e.BWT$values,
                            JPC26.H.e.CdW$values)

JPC26.H.e.raw <- rename(JPC26.H.e.raw,
                        c("Depth" = "JPC26.H.e.depth.values",
                          "median_age" = "apply.JPC26.H.e.ae.values..1..median.",
                          "LiCa" = "JPC26.H.e.LiCa.values",
                          "MgCa" = "JPC26.H.e.MgCa.values",
                          "MgLi" = "JPC26.H.e.MgLi.values",
                          "CdCa" = "JPC26.H.e.CdCa.values",
                          "BWT" = "JPC26.H.e.BWT.values",
                          "CdW" = "JPC26.H.e.CdW.values"))

write.csv(JPC26.H.e.raw, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\JPC26.H.e.raw.csv",row.names = FALSE)

JPC26.I.so.raw <- data.frame(JPC26.I.so.depth$values,
                             apply(JPC26.I.so.ae$values, 1, median),
                             JPC26.I.so.d13C$values,
                             JPC26.I.so.d18O$values
)

JPC26.I.so.raw <- rename(JPC26.I.so.raw,
                         c("Depth" = "JPC26.I.so.depth.values",
                           "median_age" = "apply.JPC26.I.so.ae.values..1..median.",
                           "LiCa" = "JPC26.I.so.d13C.values",
                           "MgCa" = "JPC26.I.so.d18O.values"
                         ))

write.csv(JPC26.I.so.raw, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\JPC26.I.so.raw.csv",row.names = FALSE)



BWT.plot <- JPC26.H.e.raw %>%
  ggplot()+
  geom_point(aes(x = median_age/1000, y = BWT))+
  geom_line(aes(x = median_age/1000, y = BWT))+
  theme_bw()+
  theme(axis.line = element_line(color='black'),
        plot.background = element_blank(),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank())+
  #theme(legend.position="none")+
  ggtitle("BWT")

print(BWT.plot)

CdW.plot <- JPC26.H.e.raw %>%
  ggplot()+
  geom_point(aes(x = median_age/1000, y = CdW))+
  geom_line(aes(x = median_age/1000, y = CdW))+
  theme_bw()+
  theme(axis.line = element_line(color='black'),
        plot.background = element_blank(),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank())+
  #theme(legend.position="none")+
  ggtitle("CdW")

print(CdW.plot)


## Extract median ensemble
#BWT
JPC26.H.e.BWT.rec05 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,Y = JPC26.H.e.BWT, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.H.e.BWT.rec05 <- rename(JPC26.H.e.BWT.rec05,c("median_BWT" = "0.5"))

JPC26.H.e.BWT.rec025 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,Y = JPC26.H.e.BWT, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.H.e.BWT.rec025 <- rename(JPC26.H.e.BWT.rec025,c("lower025_BWT" = "0.25"))

JPC26.H.e.BWT.rec075 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,Y = JPC26.H.e.BWT, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.H.e.BWT.rec075 <- rename(JPC26.H.e.BWT.rec075,c("upper075_BWT" = "0.75"))

JPC26.H.e.BWT.rec0025 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,Y = JPC26.H.e.BWT, probs = 0.025, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.H.e.BWT.rec0025 <- rename(JPC26.H.e.BWT.rec0025,c("lower0025_BWT" = "0.025"))

JPC26.H.e.BWT.rec0975 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,Y = JPC26.H.e.BWT, probs = 0.975, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.H.e.BWT.rec0975 <- rename(JPC26.H.e.BWT.rec0975,c("upper0975_BWT" = "0.975"))

#CdW
JPC26.H.e.CdW.rec05 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,Y = JPC26.H.e.CdW, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.H.e.CdW.rec05 <- rename(JPC26.H.e.CdW.rec05,c("median_CdW" = "0.5"))

JPC26.H.e.CdW.rec025 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,Y = JPC26.H.e.CdW, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.H.e.CdW.rec025 <- rename(JPC26.H.e.CdW.rec025,c("lower025_CdW" = "0.25"))

JPC26.H.e.CdW.rec075 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,Y = JPC26.H.e.CdW, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.H.e.CdW.rec075 <- rename(JPC26.H.e.CdW.rec075,c("upper075_CdW" = "0.75"))

JPC26.H.e.CdW.rec0025 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,Y = JPC26.H.e.CdW, probs = 0.025, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.H.e.CdW.rec0025 <- rename(JPC26.H.e.CdW.rec0025,c("lower0025_CdW" = "0.025"))

JPC26.H.e.CdW.rec0975 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,Y = JPC26.H.e.CdW, probs = 0.975, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.H.e.CdW.rec0975 <- rename(JPC26.H.e.CdW.rec0975,c("upper0975_CdW" = "0.975"))


JPC26.H.e.rec <- data.frame(JPC26.H.e.BWT.rec05$ages,
                            JPC26.H.e.BWT.rec05$median_BWT,
                            JPC26.H.e.BWT.rec025$lower025_BWT,
                            JPC26.H.e.BWT.rec075$upper075_BWT,
                            JPC26.H.e.BWT.rec0025$lower0025_BWT,
                            JPC26.H.e.BWT.rec0975$upper0975_BWT,
                            JPC26.H.e.CdW.rec05$median_CdW,
                            JPC26.H.e.CdW.rec025$lower025_CdW,
                            JPC26.H.e.CdW.rec075$upper075_CdW,
                            JPC26.H.e.CdW.rec0025$lower0025_CdW,
                            JPC26.H.e.CdW.rec0975$upper0975_CdW)

JPC26.H.e.rec <- rename(JPC26.H.e.rec,c("age" = "JPC26.H.e.BWT.rec05.ages",
                                        "median_BWT" = "JPC26.H.e.BWT.rec05.median_BWT",
                                        "lower025_BWT" = "JPC26.H.e.BWT.rec025.lower025_BWT",
                                        "upper075_BWT" = "JPC26.H.e.BWT.rec075.upper075_BWT",
                                        "lower005_BWT" = "JPC26.H.e.BWT.rec0025.lower0025_BWT",
                                        "upper095_BWT" = "JPC26.H.e.BWT.rec0975.upper0975_BWT",
                                        "median_CdW" = "JPC26.H.e.CdW.rec05.median_CdW",
                                        "lower025_CdW" = "JPC26.H.e.CdW.rec025.lower025_CdW",
                                        "upper075_CdW" = "JPC26.H.e.CdW.rec075.upper075_CdW",
                                        "lower005_CdW" = "JPC26.H.e.CdW.rec0025.lower0025_CdW",
                                        "upper095_CdW" = "JPC26.H.e.CdW.rec0975.upper0975_CdW"))

write.csv(JPC26.H.e.rec, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\JPC26.H.e.rib.csv",row.names = FALSE)

#d13C
JPC26.I.so.d13C.rec05 <- plotTimeseriesEnsRibbons(X = JPC26.I.so.ae,Y = JPC26.I.so.d13C, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.I.so.d13C.rec05 <- rename(JPC26.I.so.d13C.rec05,c("median_d13C" = "0.5"))

JPC26.I.so.d13C.rec025 <- plotTimeseriesEnsRibbons(X = JPC26.I.so.ae,Y = JPC26.I.so.d13C, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.I.so.d13C.rec025 <- rename(JPC26.I.so.d13C.rec025,c("lower025_d13C" = "0.25"))

JPC26.I.so.d13C.rec075 <- plotTimeseriesEnsRibbons(X = JPC26.I.so.ae,Y = JPC26.I.so.d13C, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.I.so.d13C.rec075 <- rename(JPC26.I.so.d13C.rec075,c("upper075_d13C" = "0.75"))

JPC26.I.so.d13C.rec0025 <- plotTimeseriesEnsRibbons(X = JPC26.I.so.ae,Y = JPC26.I.so.d13C, probs = 0.025, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.I.so.d13C.rec0025 <- rename(JPC26.I.so.d13C.rec0025,c("lower0025_d13C" = "0.025"))

JPC26.I.so.d13C.rec0975 <- plotTimeseriesEnsRibbons(X = JPC26.I.so.ae,Y = JPC26.I.so.d13C, probs = 0.975, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.I.so.d13C.rec0975 <- rename(JPC26.I.so.d13C.rec0975,c("upper0975_d13C" = "0.975"))

#d18O
JPC26.I.so.d18O.rec05 <- plotTimeseriesEnsRibbons(X = JPC26.I.so.ae,Y = JPC26.I.so.d18O, probs = 0.5, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.I.so.d18O.rec05 <- rename(JPC26.I.so.d18O.rec05,c("median_d18O" = "0.5"))

JPC26.I.so.d18O.rec025 <- plotTimeseriesEnsRibbons(X = JPC26.I.so.ae,Y = JPC26.I.so.d18O, probs = 0.25, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.I.so.d18O.rec025 <- rename(JPC26.I.so.d18O.rec025,c("lower025_d18O" = "0.25"))

JPC26.I.so.d18O.rec075 <- plotTimeseriesEnsRibbons(X = JPC26.I.so.ae,Y = JPC26.I.so.d18O, probs = 0.75, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.I.so.d18O.rec075 <- rename(JPC26.I.so.d18O.rec075,c("upper075_d18O" = "0.75"))

JPC26.I.so.d18O.rec0025 <- plotTimeseriesEnsRibbons(X = JPC26.I.so.ae,Y = JPC26.I.so.d18O, probs = 0.025, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.I.so.d18O.rec0025 <- rename(JPC26.I.so.d18O.rec0025,c("lower0025_d18O" = "0.025"))

JPC26.I.so.d18O.rec0975 <- plotTimeseriesEnsRibbons(X = JPC26.I.so.ae,Y = JPC26.I.so.d18O, probs = 0.975, limit.outliers.x = 0.025, export.quantiles = TRUE)
JPC26.I.so.d18O.rec0975 <- rename(JPC26.I.so.d18O.rec0975,c("upper0975_d18O" = "0.975"))


JPC26.I.so.rec <- data.frame(JPC26.I.so.d13C.rec05$ages,
                             JPC26.I.so.d13C.rec05$median_d13C,
                             JPC26.I.so.d13C.rec025$lower025_d13C,
                             JPC26.I.so.d13C.rec075$upper075_d13C,
                             JPC26.I.so.d13C.rec0025$lower0025_d13C,
                             JPC26.I.so.d13C.rec0975$upper0975_d13C,
                             JPC26.I.so.d18O.rec05$median_d18O,
                             JPC26.I.so.d18O.rec025$lower025_d18O,
                             JPC26.I.so.d18O.rec075$upper075_d18O,
                             JPC26.I.so.d18O.rec0025$lower0025_d18O,
                             JPC26.I.so.d18O.rec0975$upper0975_d18O)

JPC26.I.so.rec <- rename(JPC26.I.so.rec,c("age" = "JPC26.I.so.d13C.rec05.ages",
                                          "median_d13C" = "JPC26.I.so.d13C.rec05.median_d13C",
                                          "lower025_d13C" = "JPC26.I.so.d13C.rec025.lower025_d13C",
                                          "upper075_d13C" = "JPC26.I.so.d13C.rec075.upper075_d13C",
                                          "lower005_d13C" = "JPC26.I.so.d13C.rec0025.lower0025_d13C",
                                          "upper095_d13C" = "JPC26.I.so.d13C.rec0975.upper0975_d13C",
                                          "median_d18O" = "JPC26.I.so.d18O.rec05.median_d18O",
                                          "lower025_d18O" = "JPC26.I.so.d18O.rec025.lower025_d18O",
                                          "upper075_d18O" = "JPC26.I.so.d18O.rec075.upper075_d18O",
                                          "lower005_d18O" = "JPC26.I.so.d18O.rec0025.lower0025_d18O",
                                          "upper095_d18O" = "JPC26.I.so.d18O.rec0975.upper0975_d18O"))

write.csv(JPC26.I.so.rec, "D:\\WHOI\\Research\\Holocene_AMOC\\geoChronR\\Data_table\\JPC26.I.so.rib.csv",row.names = FALSE)


#Plot ribbons and raw data
JPC26.H.e.BWT.plot1 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,
                                                 Y = JPC26.H.e.BWT,
                                                 probs = c(0.025, 0.25, 0.5, 0.75, 0.975),
                                                 n.bins = 200,
                                                 alp = 0.2, 
                                                 color.low = "Blue",
                                                 color.high = "Blue",
                                                 color.line = "Blue"
                                                )+
  xlim(c(0,35000))+
  ylim(c(0,15))+
  ggtitle("JPC26 H.e. BWT")

JPC26.H.e.BWT.plot2 <- plotScatterEns(X = apply(JPC26.H.e.ae$values, 1, median), Y = JPC26.H.e.BWT$values, alp = 1, add.to.plot = JPC26.H.e.BWT.plot1)

print(JPC26.H.e.BWT.plot2)

#Plot ribbons and raw  data
JPC26.H.e.CdW.plot1 <- plotTimeseriesEnsRibbons(X = JPC26.H.e.ae,
                                                Y = JPC26.H.e.CdW,
                                                probs = c(0.025, 0.25, 0.5, 0.75, 0.975),
                                                n.bins = 209,
                                                alp = 0.2, 
                                                color.low = "Blue",
                                                color.high = "Blue",
                                                color.line = "Blue"
)+
  xlim(c(0,35000))+
  ylim(c(0,0.8))+
  ggtitle("JPC26 H.e. CdW")

JPC26.H.e.CdW.plot2 <- plotScatterEns(X = apply(JPC26.H.e.ae$values, 1, median), Y = JPC26.H.e.CdW$values, alp = 1, add.to.plot = JPC26.H.e.CdW.plot1)

print(JPC26.H.e.CdW.plot2)
